@@ -12,7 +12,7 @@ import weatherforecastcli.utils as utils
 import weatherforecastcli.config as config
 
 app = typer.Typer(help="Weather forecast CLI.")
-console = Console()
+console = Console(style="white on grey15")
 
 
 @app.command()
